==> libnc-dap_3.5.1.orig.tar.gz: libnc-dap-3.5.1.orig/ncdump/testsuite/dncdump.0/urls.tcl <==

# $Id: urls.tcl,v 1.1 2005/04/18 19:34:03 jimg Exp $

# Datasets and their expected output (the information that asciival sends to
# stdout - not the stuff that should be going into the file).

# URLs to a single level Sequence of atomic types

set avhrr_file_server_3_4 "http://test.opendap.org/opendap-3.4/nph-dods/data/ff/1998-6-avhrr.dat"
set avhrr_file_server_3_5 "http://test.opendap.org/opendap-3.5/nph-dods/data/ff/1998-6-avhrr.dat"

set avhrr_file_server_3_4_2 "\\\[limit=10\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_3 "\\\[limit-GSO_AVHRR=27\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_4 "\\\[limit-GSO_AVHRR=27\\\]\\\[limit-GSO_AVHRR.day_num=7\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_5 "\\\[limit-GSO_AVHRR=13\\\]$avhrr_file_server_3_4"

set avhrr_file_server_3_5_2 "\\\[limit=10\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_3 "\\\[limit-GSO_AVHRR=27\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_4 "\\\[limit-GSO_AVHRR=27\\\]\\\[limit-GSO_AVHRR.day_num=7\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_5 "\\\[limit-GSO_AVHRR=13\\\]$avhrr_file_server_3_5"

set ce1 "GSO_AVHRR.day_num"
set ce2 "GSO_AVHRR.DODS_URL"
set ce1_1 "GSO_AVHRR.day_num&GSO_AVHRR.day_num>160"

# URLs to a Structure of Arrays and to a Structure-Sequence-Structure variable.

set nscat "http://test.opendap.org/opendap-3.4/nph-dods/data/hdf/1990-S1700101.HDF"

# ce3: an array inside a structure; three \\\ needed because eval by tcl
# removes one level and another level is needed by the shell.
set ce3 "NSCAT\\\ Rev\\\ 17.WVC_Lat"
# ce4 a field in a structure in a sequence in a structure.
set ce4 "NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0"
set ce4_1 "NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0&NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0>0"

==> libnc-dap_3.6.0.orig.tar.gz: libnc-dap-3.6.0.orig/ncdump/testsuite/dncdump.0/urls.tcl <==

# $Id: urls.tcl 11906 2005-08-08 19:51:43Z root $

# Datasets and their expected output (the information that asciival sends to
# stdout - not the stuff that should be going into the file).

# URLs to a single level Sequence of atomic types

set avhrr_file_server_3_4 "http://test.opendap.org/opendap-3.4/nph-dods/data/ff/1998-6-avhrr.dat"

# This is really a misnomer. It's not the 3.5 server we're testing but the
# current release server. It's 3.4 right now (7/19/05) and will be 3.5 soon
# (8/1/05?). jhrg
set avhrr_file_server_3_5 "http://test.opendap.org/opendap/nph-dods/data/ff/1998-6-avhrr.dat"

set avhrr_file_server_3_4_2 "\\\[limit=10\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_3 "\\\[limit-GSO_AVHRR=27\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_4 "\\\[limit-GSO_AVHRR=27\\\]\\\[limit-GSO_AVHRR.day_num=7\\\]$avhrr_file_server_3_4"
set avhrr_file_server_3_4_5 "\\\[limit-GSO_AVHRR=13\\\]$avhrr_file_server_3_4"

set avhrr_file_server_3_5_2 "\\\[limit=10\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_3 "\\\[limit-GSO_AVHRR=27\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_4 "\\\[limit-GSO_AVHRR=27\\\]\\\[limit-GSO_AVHRR.day_num=7\\\]$avhrr_file_server_3_5"
set avhrr_file_server_3_5_5 "\\\[limit-GSO_AVHRR=13\\\]$avhrr_file_server_3_5"

set ce1 "GSO_AVHRR.day_num"
set ce2 "GSO_AVHRR.DODS_URL"
set ce1_1 "GSO_AVHRR.day_num&GSO_AVHRR.day_num>160"

# URLs to a Structure of Arrays and to a Structure-Sequence-Structure variable.

set nscat "http://test.opendap.org/opendap-3.4/nph-dods/data/hdf/1990-S1700101.HDF"

# ce3: an array inside a structure; three \\\ needed because eval by tcl
# removes one level and another level is needed by the shell.
set ce3 "NSCAT\\\ Rev\\\ 17.WVC_Lat"
# ce4 a field in a structure in a sequence in a structure.
set ce4 "NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0"
set ce4_1 "NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0&NSCAT\\\ Rev\\\ 17.SwathIndex.begin.begin__0>0"
